@@ -55,16 +55,6 @@ class BaseDB(ABC):
             yield result
             db.client.close()
 
-    @contextlib.asynccontextmanager
-    async def Put(self, table, data):
-        db = await self.connect(table)
-        result = None
-        try:
-            result = db.put(data)
-        finally:
-            yield result
-            db.client.close()
-
     @contextlib.asynccontextmanager
     async def Get(self, table, key=None, keys=None):
         result, db = await self.connect(table), None
@@ -114,6 +104,16 @@ class BaseDB(ABC):
 
 class CustomDB(BaseDB):
     
+    @contextlib.asynccontextmanager
+    async def Put(self, table, data):
+        db = await self.connect(table)
+        result = None
+        try:
+            result = db.put(data)
+        finally:
+            yield result
+            db.client.close()
+    
     @contextlib.asynccontextmanager
     async def GetOrCreate(self, table: str, data: Dict[ str, Any ]):
         code = data.get('meta', {}).get('code', None) 
@@ -223,7 +223,7 @@ class DefaultDB(BaseDB):
         super().__init__(key=key or settings.config.get('DEFAULT'))
         
         
-class LogDB(BaseDB):
+class LogDB(CustomDB):
     '''
     Needs LOG and key value in .env file at working directory
     It will use the CLIENT key if LOG is not found.
