@@ -4,7 +4,6 @@
 """BaseEnum module"""
 
 __all__ = [
-    'Cid10',
     'Variable',
     'BaseEnum',
     'StrEnum', 
@@ -512,17 +511,17 @@ class BodySystem(StrEnum):
     EXC = 'Excretor'
     
     
-@cache
-def get_cid10data_from_csv(csv_file):
-    data = {}
-    with open(csv_file) as file:
-        for item in csv.DictReader(file, fieldnames=['code', 'title']):
-            data[item['code']] = item['title']
-        return data 
+# @cache
+# def get_cid10data_from_csv(csv_file):
+#     data = {}
+#     with open(csv_file) as file:
+#         for item in csv.DictReader(file, fieldnames=['code', 'title']):
+#             data[item['code']] = item['title']
+#         return data 
 
 
-class Cid10Enum(BaseEnum):
-    _ignore_ = 'Cid10Enum key value' 
-    Cid10Enum = vars()
-    for key, value in get_cid10data_from_csv(settings.CID10_FILE).items():
-        Cid10Enum[key] = value
\ No newline at end of file
+# class Cid10Enum(BaseEnum):
+#     _ignore_ = 'Cid10Enum key value' 
+#     Cid10Enum = vars()
+#     for key, value in get_cid10data_from_csv(settings.CID10_FILE).items():
+#         Cid10Enum[key] = value
\ No newline at end of file
