@@ -5,6 +5,6 @@ from starlette.config import Config
 
 WORKING_DIRECTORY = os.getcwd()
 ENV_FILE = os.path.abspath('.env')
-CID10_FILE = os.path.abspath('metadoctor/cid10.csv')
+CID10_FILE = os.path.abspath('cid10.csv')
 
 config = Config(env_file=ENV_FILE)
